==> aipark-api-27.2-sources.jar: de/aipark/api/parkingarea/ParkingArea.java <==
package de.aipark.api.parkingarea;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.Point;
import de.aipark.api.chargingstation.ChargingPlugType;
import de.aipark.api.payment.PriceModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.*;

/**
 * Created by torgen on 24.08.17.
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class ParkingArea {
    @ApiModelProperty(value = "name of parking area", dataType = "java.lang.String", required = true, example = "Rathaus")
    private String name;

    @ApiModelProperty(value = "shape of parking area, e.g. multipolygon for areas or line for on street parking", required = true)
    private Geometry shape;

    @ApiModelProperty(value = "center point of parking area", required = true)
    private Point center;

    @ApiModelProperty(value = "capacity of parking area (number of spots)", dataType = "java.lang.Integer", required = true, example = "100")
    private Integer capacity;

    @ApiModelProperty(value = "type of parking area, types getting added in the future", dataType = "de.aipark.api.parkingarea.ParkingAreaType", required = true, example = "ON_STREET")
    private String parkingAreaType;

    @ApiModelProperty(value = "unique id of parking area", dataType = "java.lang.Long", required = true, example = "504838")
    private Long id;

    @ApiModelProperty(value =
            "value=null indicates no information about capacity designated for disabled, " +
                    "value>0 indicates number of spots designated for women, " +
                    "value=0 indicates no special capacity for women, " +
                    "value=-1 indicates that there are spots designated for women but capacity is unknown",
            dataType = "java.lang.Integer", example = "10")
    private Integer capacityWoman;

    @ApiModelProperty(value =
            "value=null indicates no information about capacity designated for disabled, " +
                    "value>0 indicates number of spots designated for disabled, " +
                    "value=0 indicates no special capacity for disabled, " +
                    "value=-1 indicates that there are spots designated for disabled but capacity is unknown",
            dataType = "java.lang.Integer", example = "10")
    private Integer capacityDisabled;

    @ApiModelProperty(value = "schedule when parking area is opened or closed", dataType = "MapEntry<Schedule, Boolean>")
    private MapEntry<Schedule, OpeningStatus> scheduleOpen;

    @ApiModelProperty(value = "schedule for parking disc (value = allowed time in minutes)", dataType = "MapEntry<Schedule, Boolean>")
    private MapEntry<Schedule, Integer> scheduleMaxStay;

    @ApiModelProperty(value = "price model mapping", dataType = "MapEntry<Schedule, PriceModel>")
    private MapEntry<Schedule, PriceModel> schedulePriceModel;

    @ApiModelProperty(value = "schedule with capacity of parking area (number of spots) for residential parking only", dataType = "MapEntry<Schedule, Integer>")
    private MapEntry<Schedule, Integer> scheduleResidential;

    @ApiModelProperty(value = "entrance point for parking area", dataType = "List<EntrancePoint>")
    private List<EntrancePoint> entrancePoints;

    @ApiModelProperty(value = "mapping of charging plug type to number of plugs with this type", dataType = "MapEntry<ChargingPlugType,Integer>")
    private MapEntry<ChargingPlugType, Integer> chargingPlugTypes;


    public ParkingArea() {
        scheduleOpen = new MapEntry<Schedule, OpeningStatus>();
        scheduleMaxStay = new MapEntry<Schedule, Integer>();
        schedulePriceModel = new MapEntry<Schedule, PriceModel>();
        scheduleResidential = new MapEntry<Schedule, Integer>();
        entrancePoints = new ArrayList<EntrancePoint>();
        chargingPlugTypes = new MapEntry<ChargingPlugType, Integer>();
    }

    public ParkingArea(String name, Geometry shape, Point center, Integer capacity, String parkingAreaType, Long id, Integer capacityWoman, Integer capacityDisabled, MapEntry<Schedule, OpeningStatus> scheduleOpen, MapEntry<Schedule, Integer> scheduleMaxStay, MapEntry<Schedule, PriceModel> schedulePriceModel, MapEntry<Schedule, Integer> scheduleResidential, List<EntrancePoint> entrancePoints, MapEntry<ChargingPlugType, Integer> chargingPlugTypes) {
        this.name = name;
        this.shape = shape;
        this.center = center;
        this.capacity = capacity;
        this.parkingAreaType = parkingAreaType;
        this.id = id;
        this.capacityWoman = capacityWoman;
        this.capacityDisabled = capacityDisabled;
        this.scheduleOpen = scheduleOpen;
        this.scheduleMaxStay = scheduleMaxStay;
        this.schedulePriceModel = schedulePriceModel;
        this.scheduleResidential = scheduleResidential;
        this.entrancePoints = entrancePoints;
        this.chargingPlugTypes = chargingPlugTypes;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Geometry getShape() {
        return shape;
    }

    public void setShape(Geometry shape) {
        this.shape = shape;
    }

    public Integer getCapacity() {
        return capacity;
    }

    public void setCapacity(Integer capacity) {
        this.capacity = capacity;
    }

    public ParkingAreaType getParkingAreaType() {
        try{
            return ParkingAreaType.valueOf(parkingAreaType);
        }
        catch (IllegalArgumentException e){
            return ParkingAreaType.PARKINGAREA;
        }
    }

    public void setParkingAreaType(String parkingAreaType) {
        this.parkingAreaType = parkingAreaType;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getCapacityWoman() {
        return capacityWoman;
    }

    public void setCapacityWoman(Integer capacityWoman) {
        this.capacityWoman = capacityWoman;
    }

    public Integer getCapacityDisabled() {
        return capacityDisabled;
    }

    public void setCapacityDisabled(Integer capacityDisabled) {
        this.capacityDisabled = capacityDisabled;
    }

    public MapEntry<Schedule, OpeningStatus> getScheduleOpen() {
        return scheduleOpen;
    }

    public void setScheduleOpen(MapEntry<Schedule, OpeningStatus> scheduleOpen) {
        this.scheduleOpen = scheduleOpen;
    }

    public MapEntry<Schedule, Integer> getScheduleMaxStay() {
        return scheduleMaxStay;
    }

    public void setScheduleMaxStay(MapEntry<Schedule, Integer> scheduleMaxStay) {
        this.scheduleMaxStay = scheduleMaxStay;
    }

    public MapEntry<Schedule, PriceModel> getSchedulePriceModel() {
        return schedulePriceModel;
    }

    public void setSchedulePriceModel(MapEntry<Schedule, PriceModel> schedulePriceModel) {
        this.schedulePriceModel = schedulePriceModel;
    }

    public MapEntry<Schedule, Integer> getScheduleResidential() {
        return scheduleResidential;
    }

    public void setScheduleResidential(MapEntry<Schedule, Integer> scheduleResidential) {
        this.scheduleResidential = scheduleResidential;
    }

    public List<EntrancePoint> getEntrancePoints() {
        return entrancePoints;
    }

    public void setEntrancePoints(List<EntrancePoint> entrancePoints) {
        this.entrancePoints = entrancePoints;
    }

    public MapEntry<ChargingPlugType, Integer> getChargingPlugTypes() {
        return chargingPlugTypes;
    }

    public void setChargingPlugTypes(MapEntry<ChargingPlugType, Integer> chargingPlugTypes) {
        this.chargingPlugTypes = chargingPlugTypes;
    }

    public Point getCenter() {
        return center;
    }

    public void setCenter(Point center) {
        this.center = center;
    }

    @Override
    public String toString() {
        return "ParkingArea{" +
                "name='" + name + '\'' +
                ", shape=" + shape +
                ", center=" + center +
                ", capacity=" + capacity +
                ", parkingAreaType=" + parkingAreaType +
                ", id=" + id +
                ", capacityWoman=" + capacityWoman +
                ", capacityDisabled=" + capacityDisabled +
                ", scheduleOpen=" + scheduleOpen +
                ", scheduleMaxStay=" + scheduleMaxStay +
                ", schedulePriceModel=" + schedulePriceModel +
                ", scheduleResidential=" + scheduleResidential +
                ", entrancePoints=" + entrancePoints +
                ", chargingPlugTypes=" + chargingPlugTypes +
                '}';
    }

    @JsonIgnore
    public String getPriceString() {
        ResourceBundle bundle = ResourceBundle.getBundle("Api");
        String result = "";
        Map<Schedule, List<PriceModel>> scheduleListMap = new HashMap<Schedule, List<PriceModel>>();
        for (MapEntry.Entry<Schedule, PriceModel> entry : schedulePriceModel.getEntryList()) {
            List<PriceModel> priceModels = scheduleListMap.get(entry.getKey());
            if (priceModels == null) {
                priceModels = new ArrayList<PriceModel>();
            }
            priceModels.add(entry.getValue());
            scheduleListMap.put(entry.getKey(), priceModels);
        }
        List<Schedule> schedules = new ArrayList<Schedule>(scheduleListMap.keySet());
        Collections.sort(schedules, new ScheduleComparator());
        boolean onlyDefaultPriceModels = false;
        for (Schedule schedule : schedules) {
            if (schedule.toString().isEmpty()) {
                if (schedules.size() > 1) {
                    result += bundle.getString("otherwise") + ":\n";
                } else {
                    onlyDefaultPriceModels = true;
                }
            } else {
                result += schedule.toString() + ":\n";
            }
            List<PriceModel> priceModels = new ArrayList<PriceModel>(scheduleListMap.get(schedule));
            Collections.sort(priceModels, new PriceModelComparator());
            boolean hasPeriodPricemodels = false;
            for (PriceModel priceModel : priceModels) {
                if (!onlyDefaultPriceModels) {
                    result += "\t";
                }
                if (priceModel.getFromMinute() != null || priceModel.getUntilMinute() != null) {
                    hasPeriodPricemodels = true;
                } else if (hasPeriodPricemodels && priceModel.getInterval() != null && priceModel.getMaxPriceInCent() == null) {
                    result += bundle.getString("otherwise") + " ";
                }
                result += priceModel.toString() + "\n";
            }
        }
        return result;
    }

    @JsonIgnore
    public String getMaxStayString() {
        ResourceBundle bundle = ResourceBundle.getBundle("Api");
        String result = "";
        for (MapEntry.Entry<Schedule, Integer> entry : scheduleMaxStay.getEntryList()) {
            if (!result.isEmpty()) {
                result += "\n";
            }
            result += entry.getKey().toString() + " " + bundle.getString("maximal") + " " + entry.getValue() + " " + bundle.getString("minutes");
        }
        return result;
    }

    private class ScheduleComparator implements Comparator<Schedule> {

        @Override
        public int compare(Schedule o1, Schedule o2) {
            if (o1.toString().isEmpty()) {
                return 1;
            }
            if (o2.toString().isEmpty()) {
                return -1;
            } else {
                return o1.toString().length() - o2.toString().length();
            }
        }
    }

    private class PriceModelComparator implements Comparator<PriceModel> {

        @Override
        public int compare(PriceModel o1, PriceModel o2) {
            if ((o1.getFromMinute() != null || o1.getUntilMinute() != null)
                    && (o2.getFromMinute() == null || o2.getUntilMinute() == null)) {
                return -1;
            }
            if ((o2.getFromMinute() != null || o2.getUntilMinute() != null)
                    && (o1.getFromMinute() == null || o1.getUntilMinute() == null)) {
                return 1;
            }
            if (o1.getFromMinute() != null && o2.getFromMinute() != null) {
                return o1.getFromMinute() - o2.getFromMinute();
            }
            if (o1.getUntilMinute() != null && o2.getUntilMinute() != null) {
                return o1.getUntilMinute() - o2.getUntilMinute();
            }
            if (o1.getInterval() != null && o2.getInterval() != null) {
                return o1.getInterval() - o2.getInterval();
            }
            if (o1.getInterval() != null && o2.getInterval() == null) {
                return -1;
            }
            if (o1.getInterval() == null && o2.getInterval() != null) {
                return 1;
            }
            if (o1.getMaxPriceInCent() == null && o2.getMaxPriceInCent() != null) {
                return -1;
            }
            return 0;
        }
    }
}

==> aipark-api-28.32-sources.jar: de/aipark/api/parkingarea/ParkingArea.java <==
package de.aipark.api.parkingarea;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.Point;
import de.aipark.api.chargingstation.ChargingPlugType;
import de.aipark.api.payment.PriceModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.*;

/**
 * Created by torgen on 24.08.17.
 */
@SuppressWarnings({"WeakerAccess", "unused"})
@JsonIgnoreProperties(ignoreUnknown = true)
public class ParkingArea {
    @ApiModelProperty(value = "name of parking area", dataType = "java.lang.String", required = true, example = "Rathaus")
    private String name;

    @ApiModelProperty(value = "shape of parking area, e.g. multipolygon for areas or line for on street parking", required = true)
    private Geometry shape;

    @ApiModelProperty(value = "center point of parking area", required = true)
    private Point center;

    @ApiModelProperty(value = "capacity of parking area (number of spots)", dataType = "java.lang.Integer", required = true, example = "100")
    private Integer capacity;

    @ApiModelProperty(value = "type of parking area, types getting added in the future", dataType = "de.aipark.api.parkingarea.ParkingAreaType", required = true, example = "ON_STREET")
    private String parkingAreaType;

    @ApiModelProperty(value = "orientation of parking", dataType = "de.aipark.api.parkingarea.ParkingOrientation", example = "PARALLEL")
    private ParkingOrientation parkingOrientation;// = ParkingOrientation.getDefaultValue();

    @ApiModelProperty(value = "unique id of parking area", dataType = "java.lang.Long", required = true, example = "504838")
    private Long id;

    @ApiModelProperty(value =
            "value=null indicates no information about capacity designated for disabled, " +
                    "value>0 indicates number of spots designated for women, " +
                    "value=0 indicates no special capacity for women, " +
                    "value=-1 indicates that there are spots designated for women but capacity is unknown",
            dataType = "java.lang.Integer", example = "10")
    private Integer capacityWoman;

    @ApiModelProperty(value =
            "value=null indicates no information about capacity designated for disabled, " +
                    "value>0 indicates number of spots designated for disabled, " +
                    "value=0 indicates no special capacity for disabled, " +
                    "value=-1 indicates that there are spots designated for disabled but capacity is unknown",
            dataType = "java.lang.Integer", example = "10")
    private Integer capacityDisabled;

    @ApiModelProperty(value = "schedule when parking area is opened or closed", dataType = "MapEntry<Schedule, Boolean>")
    private MapEntry<Schedule, OpeningStatus> scheduleOpen;

    @ApiModelProperty(value = "schedule for parking disc (value = allowed time in minutes)", dataType = "MapEntry<Schedule, Boolean>")
    private MapEntry<Schedule, Integer> scheduleMaxStay;

    @ApiModelProperty(value = "price model mapping", dataType = "MapEntry<Schedule, PriceModel>")
    private MapEntry<Schedule, PriceModel> schedulePriceModel;

    @ApiModelProperty(value = "schedule with capacity of parking area (number of spots) for residential parking only", dataType = "MapEntry<Schedule, Integer>")
    private MapEntry<Schedule, Integer> scheduleResidential;

    @ApiModelProperty(value = "entrance point for parking area", dataType = "List<EntrancePoint>")
    private List<EntrancePoint> entrancePoints;

    /**
     * will be removed in future release. Use special designated charging station methods.
     */
//    @JsonIgnore
    @Deprecated
    @ApiModelProperty(value = "mapping of charging plug type to number of plugs with this type", dataType = "MapEntry<ChargingPlugType,Integer>")
    private MapEntry<ChargingPlugType, Integer> chargingPlugTypes; //TODO: remove

    public ParkingArea() {
        scheduleOpen = new MapEntry<Schedule, OpeningStatus>();
        scheduleMaxStay = new MapEntry<Schedule, Integer>();
        schedulePriceModel = new MapEntry<Schedule, PriceModel>();
        scheduleResidential = new MapEntry<Schedule, Integer>();
        entrancePoints = new ArrayList<EntrancePoint>();
        chargingPlugTypes = new MapEntry<ChargingPlugType, Integer>(); //TODO: remove
    }

//    /**
//     * use other constructor, this may be removed in future release
//     */
//    @Deprecated
//    public ParkingArea(String name, Geometry shape, Point center, Integer capacity, String parkingAreaType,
//                       Long id, Integer capacityWoman, Integer capacityDisabled, MapEntry<Schedule, OpeningStatus> scheduleOpen,
//                       MapEntry<Schedule, Integer> scheduleMaxStay, MapEntry<Schedule, PriceModel> schedulePriceModel, MapEntry<Schedule,
//            Integer> scheduleResidential, List<EntrancePoint> entrancePoints, MapEntry<ChargingPlugType, Integer> chargingPlugTypes) {
//        this(name, shape, center, capacity, parkingAreaType, null, id, capacityWoman, capacityDisabled, scheduleOpen,
//                scheduleMaxStay, schedulePriceModel, scheduleResidential, entrancePoints, chargingPlugTypes);
//    }

    public ParkingArea(String name, Geometry shape, Point center, Integer capacity, String parkingAreaType, ParkingOrientation parkingOrientation,
                       Long id, Integer capacityWoman, Integer capacityDisabled, MapEntry<Schedule, OpeningStatus> scheduleOpen,
                       MapEntry<Schedule, Integer> scheduleMaxStay, MapEntry<Schedule, PriceModel> schedulePriceModel, MapEntry<Schedule,
            Integer> scheduleResidential, List<EntrancePoint> entrancePoints, MapEntry<ChargingPlugType, Integer> chargingPlugTypes) {
        this.name = name;
        this.shape = shape;
        this.center = center;
        this.capacity = capacity;
        this.parkingAreaType = parkingAreaType;
        this.parkingOrientation = parkingOrientation;
        this.id = id;
        this.capacityWoman = capacityWoman;
        this.capacityDisabled = capacityDisabled;
        this.scheduleOpen = scheduleOpen;
        this.scheduleMaxStay = scheduleMaxStay;
        this.schedulePriceModel = schedulePriceModel;
        this.scheduleResidential = scheduleResidential;
        this.entrancePoints = entrancePoints;
//        this.chargingPlugTypes = chargingPlugTypes;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Geometry getShape() {
        return shape;
    }

    public void setShape(Geometry shape) {
        this.shape = shape;
    }

    public Integer getCapacity() {
        return capacity;
    }

    public void setCapacity(Integer capacity) {
        this.capacity = capacity;
    }

    public ParkingAreaType getParkingAreaType() {
        try {
            return ParkingAreaType.valueOf(parkingAreaType);
        } catch (IllegalArgumentException e) {
            return ParkingAreaType.PARKINGAREA;
        }
    }

    public void setParkingAreaType(String parkingAreaType) {
        this.parkingAreaType = parkingAreaType;
    }

    public ParkingOrientation getParkingOrientation() {
        return parkingOrientation;
    }

    public void setParkingOrientation(ParkingOrientation parkingOrientation) {
        this.parkingOrientation = parkingOrientation;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getCapacityWoman() {
        return capacityWoman;
    }

    public void setCapacityWoman(Integer capacityWoman) {
        this.capacityWoman = capacityWoman;
    }

    public Integer getCapacityDisabled() {
        return capacityDisabled;
    }

    public void setCapacityDisabled(Integer capacityDisabled) {
        this.capacityDisabled = capacityDisabled;
    }

    public MapEntry<Schedule, OpeningStatus> getScheduleOpen() {
        return scheduleOpen;
    }

    public void setScheduleOpen(MapEntry<Schedule, OpeningStatus> scheduleOpen) {
        this.scheduleOpen = scheduleOpen;
    }

    public MapEntry<Schedule, Integer> getScheduleMaxStay() {
        return scheduleMaxStay;
    }

    public void setScheduleMaxStay(MapEntry<Schedule, Integer> scheduleMaxStay) {
        this.scheduleMaxStay = scheduleMaxStay;
    }

    public MapEntry<Schedule, PriceModel> getSchedulePriceModel() {
        return schedulePriceModel;
    }

    public void setSchedulePriceModel(MapEntry<Schedule, PriceModel> schedulePriceModel) {
        this.schedulePriceModel = schedulePriceModel;
    }

    public MapEntry<Schedule, Integer> getScheduleResidential() {
        return scheduleResidential;
    }

    public void setScheduleResidential(MapEntry<Schedule, Integer> scheduleResidential) {
        this.scheduleResidential = scheduleResidential;
    }

    public List<EntrancePoint> getEntrancePoints() {
        return entrancePoints;
    }

    public void setEntrancePoints(List<EntrancePoint> entrancePoints) {
        this.entrancePoints = entrancePoints;
    }

    /**
     * will be removed in future release. Use special designated charging station methods.
     */
//    //@JsonIgnore
    @Deprecated
    public MapEntry<ChargingPlugType, Integer> getChargingPlugTypes() { //TODO: remove
        return chargingPlugTypes;
    }

    /**
     * will be removed in future release. Use special designated charging station methods.
     */
    @Deprecated
    public void setChargingPlugTypes(MapEntry<ChargingPlugType, Integer> chargingPlugTypes) { //TODO: remove
        this.chargingPlugTypes = chargingPlugTypes;
    }

    public Point getCenter() {
        return center;
    }

    public void setCenter(Point center) {
        this.center = center;
    }

    @Override
    public String toString() {
        return "ParkingArea{" +
                "name='" + name + '\'' +
                ", shape=" + shape +
                ", center=" + center +
                ", capacity=" + capacity +
                ", parkingAreaType='" + parkingAreaType + '\'' +
                ", parkingOrientation=" + parkingOrientation +
                ", id=" + id +
                ", capacityWoman=" + capacityWoman +
                ", capacityDisabled=" + capacityDisabled +
                ", scheduleOpen=" + scheduleOpen +
                ", scheduleMaxStay=" + scheduleMaxStay +
                ", schedulePriceModel=" + schedulePriceModel +
                ", scheduleResidential=" + scheduleResidential +
                ", entrancePoints=" + entrancePoints +
//                ", chargingPlugTypes=" + chargingPlugTypes +
                '}';
    }

    @SuppressWarnings("StringConcatenationInLoop") //compatibility with js converter
    @JsonIgnore
    public String getPriceString() {
        ResourceBundle bundle = ResourceBundle.getBundle("Api");
        String result = "";
        Map<Schedule, List<PriceModel>> scheduleListMap = new HashMap<Schedule, List<PriceModel>>();
        for (MapEntry.Entry<Schedule, PriceModel> entry : schedulePriceModel.getEntryList()) {
            List<PriceModel> priceModels = scheduleListMap.get(entry.getKey());
            if (priceModels == null) {
                priceModels = new ArrayList<PriceModel>();
            }
            priceModels.add(entry.getValue());
            scheduleListMap.put(entry.getKey(), priceModels);
        }
        List<Schedule> schedules = new ArrayList<Schedule>(scheduleListMap.keySet());
        Collections.sort(schedules);
        boolean onlyDefaultPriceModels = false;
        for (Schedule schedule : schedules) {
            if (schedule.toString().isEmpty()) {
                if (schedules.size() > 1) {
                    result += bundle.getString("otherwise") + ":\n";
                } else {
                    onlyDefaultPriceModels = true;
                }
            } else {
                result += schedule.toString() + ":\n";
            }
            List<PriceModel> priceModels = new ArrayList<PriceModel>(scheduleListMap.get(schedule));
            Collections.sort(priceModels);
            boolean hasPeriodPricemodels = false;
            for (PriceModel priceModel : priceModels) {
                if (!onlyDefaultPriceModels) {
                    result += "\t";
                }
                if (priceModel.getFromMinute() != null || priceModel.getUntilMinute() != null) {
                    hasPeriodPricemodels = true;
                } else if (hasPeriodPricemodels && priceModel.getInterval() != null && priceModel.getMaxPriceInCent() == null) {
                    result += bundle.getString("otherwise") + " ";
                }
                result += priceModel.toString() + "\n";
            }
        }
        return result;
    }

    @SuppressWarnings("StringConcatenationInLoop") //compatibility with js converter
    @JsonIgnore
    public String getMaxStayString() {
        ResourceBundle bundle = ResourceBundle.getBundle("Api");
        String result = "";
        for (MapEntry.Entry<Schedule, Integer> entry : scheduleMaxStay.getEntryList()) {
            if (!result.isEmpty()) {
                result += "\n";
            }
            result += entry.getKey().toString() + " " + bundle.getString("maximal") + " " + entry.getValue() + " " + bundle.getString("minutes");
        }
        return result;
    }

    @SuppressWarnings("StringConcatenationInLoop") //compatibility with js converter
    @JsonIgnore
    public String getOpeningHoursString() {
        ResourceBundle bundle = ResourceBundle.getBundle("Api");
        String result = "";
        for(MapEntry.Entry<Schedule,OpeningStatus> entry :scheduleOpen.getEntryList()){
            String opened = bundle.getString("closed");
            if(entry.getValue().equals(OpeningStatus.OPEN)){
                    opened = bundle.getString("open");
            }
            result += entry.getKey().toString() + " " + opened + "\n";
        }
        if(result.length() > 0){
            result = result.substring(0, result.length() - 1);
        }
        return result;
    }
}
